@@ -21,13 +21,14 @@ from .core_tasks import (
     ZipFeatureTask,
 )
 from .eodata import EOPatch
-from .eoexecution import EOExecutor, execute_with_mp_lock
+from .eoexecution import EOExecutor
 from .eonode import EONode, linearly_connect_tasks
 from .eotask import EOTask
 from .eoworkflow import EOWorkflow, WorkflowResults
 from .eoworkflow_tasks import OutputTask
 from .utils.common import constant_pad, deep_eq
 from .utils.fs import get_filesystem, load_s3_filesystem
+from .utils.parallelize import execute_with_mp_lock, join_futures, join_futures_iter, parallelize
 from .utils.parsing import FeatureParser
 
-__version__ = "1.0.2"
+__version__ = "1.1.0"
