@@ -17,9 +17,12 @@ import warnings
 from collections import defaultdict
 
 import fs
+import fs.move
 import geopandas as gpd
 import numpy as np
 import pandas as pd
+from fs.base import FS
+from fs.osfs import OSFS
 from fs.tempfs import TempFS
 from geopandas import GeoDataFrame, GeoSeries
 
@@ -41,7 +44,7 @@ def save_eopatch(
     overwrite_permission=OverwritePermission.ADD_ONLY,
     compress_level=0,
 ):
-    """A utility function used by EOPatch.save method."""
+    """A utility function used by `EOPatch.save` method."""
     patch_exists = filesystem.exists(patch_location)
 
     if not patch_exists:
@@ -87,7 +90,7 @@ def save_eopatch(
 
 
 def remove_redundant_files(filesystem, eopatch_features, filesystem_features, current_compress_level):
-    """Removes files that should have been overwriten but were not due to different compression levels."""
+    """Removes files that should have been overwritten but were not due to different compression levels."""
     files_to_remove = []
     saved_features = {(ftype, fname) for ftype, fname, _ in eopatch_features}
     for ftype, fname, path in filesystem_features:
@@ -101,7 +104,7 @@ def remove_redundant_files(filesystem, eopatch_features, filesystem_features, cu
 
 
 def load_eopatch(eopatch, filesystem, patch_location, features=..., lazy_loading=False):
-    """A utility function used by EOPatch.load method."""
+    """A utility function used by `EOPatch.load` method."""
     features = list(walk_filesystem(filesystem, patch_location, features))
     loading_data = [FeatureIO(ftype, path, filesystem) for ftype, _, path in features]
 
@@ -159,7 +162,7 @@ def walk_main_folder(filesystem, folder_path):
     """Walks the main EOPatch folders and yields tuples (feature type, feature name, path in filesystem).
 
     The results depend on the implementation of `filesystem.listdir`. For each folder that coincides with a feature
-    type it returns (feature type, ..., path). If files in subfolders are also listed by `listdir` it returns the
+    type it returns (feature type, ..., path). If files in subfolders are also listed by `listdir` it returns
     them as well, which allows `walk_filesystem` to skip such subfolders from further searches.
     """
     for path in filesystem.listdir(folder_path):
@@ -233,7 +236,7 @@ def _to_lowercase(ftype, fname, *_):
 class FeatureIO:
     """A class that handles the saving and loading process of a single feature at a given location."""
 
-    def __init__(self, feature_type: FeatureType, path: str, filesystem: fs.base.FS):
+    def __init__(self, feature_type: FeatureType, path: str, filesystem: FS):
         """
         :param feature_type: A feature type
         :param path: A path in the filesystem
@@ -270,9 +273,11 @@ class FeatureIO:
         gz_extension = ("." + MimeType.GZIP.extension) if compress_level else ""
         path = f"{self.path}.{file_format.extension}{gz_extension}"
 
-        if isinstance(self.filesystem, (fs.osfs.OSFS, TempFS)):
+        if isinstance(self.filesystem, (OSFS, TempFS)):
             with TempFS(temp_dir=self.filesystem.root_path) as tempfs:
                 self._save(tempfs, data, "tmp_feature", file_format, compress_level)
+                if fs.__version__ == "2.4.16" and self.filesystem.exists(path):  # An issue in the fs version
+                    self.filesystem.remove(path)
                 fs.move.move_file(tempfs, "tmp_feature", self.filesystem, path)
             return
         self._save(self.filesystem, data, path, file_format, compress_level)
