@@ -14,6 +14,7 @@ file in the root directory of this source tree.
 """
 
 import uuid
+from typing import Union
 
 import geopandas as gpd
 import numpy as np
@@ -117,7 +118,7 @@ def constant_pad(array, multiple_of, up_down_rule="even", left_right_rule="even"
             row_padding_up = int(row_padding / 2)
             row_padding_down = row_padding_up + (row_padding % 2)
         else:
-            raise ValueError("Padding rule for rows not supported. Choose beteen even, down or up!")
+            raise ValueError("Padding rule for rows not supported. Choose between even, down or up!")
 
     if col_padding > 0:
         if left_right_rule == "left":
@@ -128,7 +129,7 @@ def constant_pad(array, multiple_of, up_down_rule="even", left_right_rule="even"
             col_padding_left = int(col_padding / 2)
             col_padding_right = col_padding_left + (col_padding % 2)
         else:
-            raise ValueError("Padding rule for columns not supported. Choose beteen even, left or right!")
+            raise ValueError("Padding rule for columns not supported. Choose between even, left or right!")
 
     return np.lib.pad(
         array,
@@ -141,7 +142,7 @@ def constant_pad(array, multiple_of, up_down_rule="even", left_right_rule="even"
 def generate_uid(prefix: str):
     """Generates a (sufficiently) unique ID starting with the `prefix`.
 
-    The ID is composed from the prefix, a hexadecimal string obtained from the current time and a random hexadecimal
+    The ID is composed of the prefix, a hexadecimal string obtained from the current time and a random hexadecimal
     string. This makes the uid sufficiently unique.
     """
     time_uid = uuid.uuid1(node=0).hex[:-12]
@@ -149,6 +150,7 @@ def generate_uid(prefix: str):
     return f"{prefix}-{time_uid}-{random_uid}"
 
 
-def is_discrete_type(number_dtype: np.dtype) -> bool:
-    """Checks if the given `numpy` number dtype is discrete"""
-    return issubclass(number_dtype.type, (np.integer, bool, np.bool_, np.bool8))
+def is_discrete_type(number_type: Union[np.dtype, type]) -> bool:
+    """Checks if a given `numpy` type is a discrete numerical type."""
+    number_dtype = np.dtype(number_type)
+    return issubclass(number_dtype.type, (np.integer, np.bool_))
